@@ -63,21 +63,20 @@ set_from_string (GValue *value, const gchar *as_string)
 	/* custom transform function */
 	retval = FALSE;
 	if (type == G_TYPE_BOOLEAN) {
-		if (((as_string[0] == 't') || (as_string[0] == 'T')) &&
-		    ((as_string[1] == 'r') || (as_string[1] == 'R')) &&
-		    ((as_string[2] == 'u') || (as_string[2] == 'U')) &&
-		    ((as_string[3] == 'e') || (as_string[3] == 'E'))) {
+		if ((as_string[0] == 't') || (as_string[0] == 'T')) {
 			g_value_set_boolean (value, TRUE);
 			retval = TRUE;
 		}
-		else if (((as_string[0] == 'f') || (as_string[0] == 'F')) &&
-			 ((as_string[1] == 'a') || (as_string[1] == 'A')) &&
-			 ((as_string[2] == 'l') || (as_string[2] == 'L')) &&
-			 ((as_string[3] == 's') || (as_string[3] == 'S')) &&
-			 ((as_string[4] == 'e') || (as_string[4] == 'E'))) {
+		else if ((as_string[0] == 'f') || (as_string[0] == 'F')) {
 			g_value_set_boolean (value, FALSE);
 			retval = TRUE;
 		}
+		else {
+			gint i;
+			i = atoi (as_string);
+			g_value_set_boolean (value, i ? TRUE : FALSE);
+			retval = TRUE;
+		}
 	}
 	else if (type == G_TYPE_INT64) {
 		gint64 i64;
@@ -283,7 +282,7 @@ binary_to_string (const GValue *src, GValue *dest)
 	
 	str = gda_binary_to_string (gda_value_get_binary ((GValue *) src), 0);
 	
-	g_value_set_string (dest, str);
+	g_value_take_string (dest, str);
 }
 
 GType
@@ -380,7 +379,7 @@ blob_to_string (const GValue *src, GValue *dest)
 	
 	str = gda_blob_to_string ((GdaBlob *) gda_value_get_blob ((GValue *) src), 0);
 	
-	g_value_set_string (dest, str);
+	g_value_take_string (dest, str);
 }
 
 GType
@@ -492,7 +491,7 @@ geometric_point_to_string (const GValue *src, GValue *dest)
 				  DBL_DIG,
 				  point->y);
 	
-	g_value_set_string(dest, str);
+	g_value_take_string (dest, str);
 }
 
 /* Transform a String GValue to a GdaGeometricPoint from a string like "(3.2,5.6)" */
@@ -949,6 +948,26 @@ gda_time_free (gpointer boxed)
 	g_free (boxed);
 }
 
+/**
+ * gda_time_valid
+ * @time: a #GdaTime value to check if it is valid
+ *
+ * Returns: #TRUE if #GdaTime is valid; FALSE otherwise.
+ *
+ * Since: 4.2
+ */
+gboolean
+gda_time_valid (const GdaTime *time)
+{
+	g_return_val_if_fail (time, FALSE);
+
+	if (time->hour < 0 || time->hour > 24 ||
+	    time->minute < 0 || time->minute > 59 ||
+	    time->second < 0 || time->second > 59)
+		return FALSE;
+	else
+		return TRUE;
+}
 
 
 /* 
@@ -1064,7 +1083,40 @@ gda_timestamp_free (gpointer boxed)
 	g_free (boxed);
 }
 
+/**
+ * gda_timestamp_valid
+ * @timestamp: a #GdaTimestamp value to check if it is valid
+ *
+ * Returns: #TRUE if #GdaTimestamp is valid; FALSE otherwise.
+ *
+ * Since: 4.2
+ */
+gboolean
+gda_timestamp_valid (const GdaTimestamp *timestamp)
+{
+	g_return_val_if_fail (timestamp, FALSE);
 
+	GDate *gdate;
+
+	/* check the date part */
+	gdate = g_date_new_dmy ((GDateDay) timestamp->day, (GDateMonth) timestamp->month,
+				(GDateYear) timestamp->year);
+	if (!gdate)
+		return FALSE;
+	if (! g_date_valid (gdate)) {
+		g_date_free (gdate);
+		return FALSE;
+	}
+	g_date_free (gdate);
+
+	/* check the time part */
+	if (timestamp->hour < 0 || timestamp->hour > 24 ||
+	    timestamp->minute < 0 || timestamp->minute > 59 ||
+	    timestamp->second < 0 || timestamp->second > 59)
+		return FALSE;
+	else
+		return TRUE;
+}
 
 /**
  * gda_value_new
@@ -1756,7 +1808,7 @@ gda_value_set_timestamp (GValue *value, const GdaTimestamp *val)
  *
  * Returns: %TRUE if the value has been converted to @type from
  * its string representation; it not means that the value is converted 
- * successfully, just that the transformation is avairable. %FALSE otherwise.
+ * successfully, just that the transformation is available. %FALSE otherwise.
  */
 gboolean
 gda_value_set_from_string (GValue *value, 
